@@ -196,8 +196,8 @@ UUBrokenByNetscape (char *string)
   if (string==NULL || (len=strlen(string))<3)
     return 0;
 
-  if ((ptr = FP_stristr (string, "<a href=")) != NULL) {
-    if (FP_stristr (string, "</a>") > ptr)
+  if ((ptr = _FP_stristr (string, "<a href=")) != NULL) {
+    if (_FP_stristr (string, "</a>") > ptr)
       return 2;
   }
 
@@ -207,7 +207,7 @@ UUBrokenByNetscape (char *string)
   if (*--ptr == ' ') ptr--;
   ptr--;
 
-  if (FP_strnicmp (ptr, "<a", 2) == 0)
+  if (_FP_strnicmp (ptr, "<a", 2) == 0)
     return 1;
 
   return 0;
@@ -217,7 +217,7 @@ UUBrokenByNetscape (char *string)
  * Try to repair a Netscape-corrupted line of data.
  * This must only be called on corrupted lines, since non-Netscape
  * data may even _get_ corrupted by this procedure.
- *
+ * 
  * Some checks are included multiply to speed up the procedure. For
  * example: (*p1!='<' || strnicmp(p1,"</a>",4)). If the first expression
  * becomes true, the costly function isn't called :-)
@@ -241,9 +241,9 @@ UUNetscapeCollapse (char *string)
    */
   while (*p1) {
     if (*p1 == '&') {
-      if      (FP_strnicmp (p1, "&amp;", 5) == 0) { p1+=5; *p2++='&'; res=1; }
-      else if (FP_strnicmp (p1, "&lt;",  4) == 0) { p1+=4; *p2++='<'; res=1; }
-      else if (FP_strnicmp (p1, "&gt;",  4) == 0) { p1+=4; *p2++='>'; res=1; }
+      if      (_FP_strnicmp (p1, "&amp;", 5) == 0) { p1+=5; *p2++='&'; res=1; }
+      else if (_FP_strnicmp (p1, "&lt;",  4) == 0) { p1+=4; *p2++='<'; res=1; }
+      else if (_FP_strnicmp (p1, "&gt;",  4) == 0) { p1+=4; *p2++='>'; res=1; }
       else *p2++ = *p1++;
       res = 1;
     }
@@ -257,16 +257,16 @@ UUNetscapeCollapse (char *string)
 
   while (*p1) {
     if (*p1 == '<') {
-      if ((FP_strnicmp (p1, "<ahref=", 7) == 0 ||
-	   FP_strnicmp (p1, "<a href=",8) == 0) &&
-	  (FP_strstr (p1, "</a>") != 0 || FP_strstr (p1, "</A>") != 0)) {
+      if ((_FP_strnicmp (p1, "<ahref=", 7) == 0 ||
+	   _FP_strnicmp (p1, "<a href=",8) == 0) && 
+	  (_FP_strstr (p1, "</a>") != 0 || _FP_strstr (p1, "</A>") != 0)) {
 	while (*p1 && *p1!='>')        p1++;
 	if (*p1=='\0' || *(p1+1)!='<') return 0;
 	p1++;
-	while (*p1 && (*p1!='<' || FP_strnicmp(p1,"</a>",4)!=0)) {
+	while (*p1 && (*p1!='<' || _FP_strnicmp(p1,"</a>",4)!=0)) {
 	  *p2++ = *p1++;
 	}
-	if (FP_strnicmp(p1,"</a>",4) != 0)
+	if (_FP_strnicmp(p1,"</a>",4) != 0)
 	  return 0;
 	p1+=4;
 	res=1;
@@ -300,10 +300,14 @@ UUValidData (char *ptr, int encoding, int *bhflag)
     return 0;              /* bad string */
   }
 
-  if (encoding == YENC_ENCODED)
-    return YENC_ENCODED;
+  while (*s) {
+    s++;
+    len++;
+    i++;
+  }
 
-  i = strlen (s);
+  if (i == 0)
+    return 0;
 
   switch (encoding) {
   case UU_ENCODED:
@@ -314,6 +318,8 @@ UUValidData (char *ptr, int encoding, int *bhflag)
     goto _t_B64;
   case BH_ENCODED:
     goto _t_Binhex;
+  case YENC_ENCODED:
+    return YENC_ENCODED;
   }
 
  _t_Binhex:                 /* Binhex Test */
@@ -536,7 +542,7 @@ UURepairData (FILE *datei, char *line, int encoding, int *bhflag)
       if (strlen (line) > 250)
 	break;
       ptr = line + strlen (line);
-      if (FP_fgets (ptr, 299-(ptr-line), datei) == NULL)
+      if (_FP_fgets (ptr, 299-(ptr-line), datei) == NULL)
 	break;
     }
     else {			/* don't need next line to repair */
@@ -603,25 +609,7 @@ UUDecodeLine (char *s, char *d, int method)
    */
   z1 = z2 = z3 = z4 = 0;
 
-  if (method == YENC_ENCODED) {
-    while (*s) {
-      if (ecb_expect_false (*s == '=')) {
-	if (*++s != '\0') {
-	  d[count++] = (char) ((int) *s - 64 - 42);
-	  s++;
-	}
-      }
-      #if 0 /* FP_fgets never leaves CR or LF in the buffer, so skip this */
-      else if (ecb_expect_false (*s == '\n' || *s == '\r')) {
-	s++; /* ignore */
-      }
-      #endif
-      else {
-	d[count++] = (char) ((int) *s++ - 42);
-      }
-    }
-  }
-  else if (method == UU_ENCODED || method == XX_ENCODED) {
+  if (method == UU_ENCODED || method == XX_ENCODED) {
     if (method == UU_ENCODED)
       table = UUxlat;
     else
@@ -637,20 +625,20 @@ UUDecodeLine (char *s, char *d, int method)
 
       if(i-- > 0)
 	d[count++] = c;
-
+      
       cc <<= 4;
       c    = table[ACAST(*s++)];
       cc  |= (c >> 2);
-
+      
       if(i-- > 0)
 	d[count++] = cc;
-
+      
       c <<= 6;
       c |= table[ACAST(*s++)];
-
+      
       if(i-- > 0)
 	d[count++] = c;
-
+      
       j -= 4;
     }
   }
@@ -718,6 +706,22 @@ UUDecodeLine (char *s, char *d, int method)
     while (BHxlat[ACAST(*s)] != -1)
       uuncdl_fulline[leftover++] = *s++;
   }
+  else if (method == YENC_ENCODED) {
+    while (*s) {
+      if (*s == '=') {
+	if (*++s != '\0') {
+	  d[count++] = (char) ((int) *s - 64 - 42);
+	  s++;
+	}
+      }
+      else if (*s == '\n' || *s == '\r') {
+	s++; /* ignore */
+      }
+      else {
+	d[count++] = (char) ((int) *s++ - 42);
+      }
+    }
+  }
 
   return count;
 }
@@ -736,10 +740,10 @@ UUDecodeQP (FILE *datain, FILE *dataout, int *state,
 
   uulboundary = -1;
 
-  while (!FP_feof (datain) &&
+  while (!feof (datain) && 
 	 (ftell(datain)<maxpos || flags&FL_TOEND ||
 	  (!(flags&FL_PROPER) && uu_fast_scanning))) {
-    if (FP_fgets (line, 1023, datain) == NULL)
+    if (_FP_fgets (line, 1023, datain) == NULL)
       break;
     if (ferror (datain)) {
       UUMessage (uunconc_id, __LINE__, UUMSG_ERROR,
@@ -785,7 +789,7 @@ UUDecodeQP (FILE *datain, FILE *dataout, int *state,
       }
       else if (!*p2) {
 	/* soft line break */
-        goto skip_lbr;
+	*p2 = '\0';
 	break;
       }
       else {
@@ -793,16 +797,6 @@ UUDecodeQP (FILE *datain, FILE *dataout, int *state,
 	fputc ('=', dataout);
       }
     }
-    /*
-     * p2 points to a nullbyte right after the CR/LF/CRLF
-     */
-    val = 0;
-    while (p2>p1 && isspace (*(p2-1))) {
-      if (*(p2-1) == '\012' || *(p2-1) == '\015')
-        val = 1;
-      p2--;
-    }
-    *p2 = '\0';
 
     /*
      * If the part ends directly after this line, the data does not end
@@ -811,14 +805,12 @@ UUDecodeQP (FILE *datain, FILE *dataout, int *state,
      * So if the part ends here, don't print a line break"
      */
     /* something is broken here now, but it was broken before */
-    if (!FP_feof (datain) &&
+    if (!feof (datain) && 
 	(ftell(datain)<maxpos || flags&FL_TOEND ||
 	 (!(flags&FL_PROPER) && uu_fast_scanning)))
       fprintf (dataout, "%s\n", p1);
     else
       fprintf (dataout, "%s", p1);
-
-    skip_lbr: ;
   }
   return UURET_OK;
 }
@@ -836,10 +828,10 @@ UUDecodePT (FILE *datain, FILE *dataout, int *state,
 
   uulboundary = -1;
 
-  while (!FP_feof (datain) &&
+  while (!feof (datain) && 
 	 (ftell(datain)<maxpos || flags&FL_TOEND ||
 	  (!(flags&FL_PROPER) && uu_fast_scanning))) {
-    if (FP_fgets (line, 1023, datain) == NULL)
+    if (_FP_fgets (line, 1023, datain) == NULL)
       break;
     if (ferror (datain)) {
       UUMessage (uunconc_id, __LINE__, UUMSG_ERROR,
@@ -956,16 +948,16 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
   char *line, *oline=uuncdp_oline;
   int warning=0, vlc=0, lc[2], hadct=0;
   int tc=0, tf=0, vflag, haddata=0, haddh=0;
-  long yefilesize=0, yepartends=0, yenotlastpart=0;
-  crc32_t yepartcrc=CRC32_INIT;
-  static crc32_t yefilecrc;
+  long yefilesize=0, yepartends=0;
+  crc32_t yepartcrc=crc32(0L, Z_NULL, 0);
+  static crc32_t yefilecrc=0;
   static int bhflag=0;
   size_t count=0;
   size_t yepartsize=0;
   char *ptr;
 
   if (datain == NULL || dataout == NULL) {
-    yefilecrc = CRC32_INIT;
+    yefilecrc = crc32(0L, Z_NULL, 0);
     bhflag = 0;
     return UURET_OK;
   }
@@ -990,10 +982,10 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
     *state = BEGIN;
   }
 
-  while (!FP_feof (datain) && *state != DONE &&
+  while (!feof (datain) && *state != DONE && 
 	 (ftell(datain)<maxpos || flags&FL_TOEND || maxpos==-1 ||
 	  (!(flags&FL_PROPER) && uu_fast_scanning))) {
-    if (FP_fgets ((line = uugen_fnbuffer), 1200 - 5, datain) == NULL)
+    if (_FP_fgets ((line = uugen_fnbuffer), 1200 - 5, datain) == NULL)
       break;
 
     /* optionally skip .. */
@@ -1024,7 +1016,7 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
       vlc = 0;
       continue;
     }
-
+    
     /*
      * Busy Polls
      */
@@ -1057,7 +1049,7 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 
     if ((flags&FL_PROPER) == 0) {
       if (strncmp (line, "BEGIN", 5) == 0 &&
-	  FP_strstr  (line, "CUT HERE")  && !tf) { /* I hate these lines */
+	  _FP_strstr  (line, "CUT HERE")  && !tf) { /* I hate these lines */
 	tc = tf = vlc = 0;
 	continue;
       }
@@ -1073,14 +1065,14 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 	haddh = 1;
 	continue;
       }
-      if (FP_strnicmp (line, "Content-Type", 12) == 0)
+      if (_FP_strnicmp (line, "Content-Type", 12) == 0)
 	hadct = 1;
     }
 
     if (*state == BEGIN) {
       if ((method == UU_ENCODED || method == XX_ENCODED) &&
 	  (strncmp      (line, "begin ",       6) == 0 ||
-	   FP_strnicmp (line, "<pre>begin ", 11) == 0)) { /* for LYNX */
+	   _FP_strnicmp (line, "<pre>begin ", 11) == 0)) { /* for LYNX */
 	*state = DATA;
 	continue;
       }
@@ -1094,10 +1086,10 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
       }
       else if (method == YENC_ENCODED &&
 	       strncmp (line, "=ybegin ", 8) == 0 &&
-	       FP_strstr (line, " name=") != NULL) {
+	       _FP_strstr (line, " name=") != NULL) {
 	*state = DATA;
 
-	if ((ptr = FP_strstr (line, " size=")) != NULL) {
+	if ((ptr = _FP_strstr (line, " size=")) != NULL) {
 	  ptr += 6;
 	  yefilesize = atoi (ptr);
 	}
@@ -1105,20 +1097,15 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 	  yefilesize = -1;
 	}
 
-	if ((ptr =FP_strstr (line, " part="))) {
-          int partno = atoi (ptr + 6);
-
-	  if ((ptr = FP_strstr (line, " total=")))
-            yenotlastpart = atoi (ptr + 7) != partno;
-
-	  if (FP_fgets (line, 1200 - 5, datain) == NULL) {
+	if (_FP_strstr (line, " part=") != NULL) {
+	  if (_FP_fgets (line, 1200 - 5, datain) == NULL) {
 	    break;
 	  }
 
-	  if ((ptr = FP_strstr (line, " end=")) == NULL) {
+	  if ((ptr = _FP_strstr (line, " end=")) == NULL) {
 	    break;
 	  }
-
+       
 	  yepartends = atoi (ptr + 5);
 	}
 	tf = 1;
@@ -1127,11 +1114,11 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
       else {
 	continue;
       }
-
+      
       tc = tf = vlc = 0;
       lc[0] = lc[1] = 0;
     }
-    else if ((*state == END || *state == DATA) &&
+    else if ((*state == END) &&
 	     (method == UU_ENCODED || method == XX_ENCODED)) {
       if (strncmp (line, "end", 3) == 0) {
 	*state = DONE;
@@ -1141,22 +1128,14 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 
     if (*state == DATA && method == YENC_ENCODED &&
 	strncmp (line, "=yend ", 6) == 0) {
-      int lastpart = !yenotlastpart && (yepartends == 0 || yepartends >= yefilesize);
-      yefilecrc = uu_crc32_combine(yefilecrc, yepartcrc, yepartsize);
-      if ((ptr = FP_strstr (line, " pcrc32=")) != NULL) {
+      if ((ptr = _FP_strstr (line, " pcrc32=")) != NULL) {
 	crc32_t pcrc32 = strtoul (ptr + 8, NULL, 16);
 	if (pcrc32 != yepartcrc) {
 	  UUMessage (uunconc_id, __LINE__, UUMSG_WARNING,
 		     uustring (S_PCRC_MISMATCH), progress.curfile, progress.partno);
 	}
-      } else if ((ptr = FP_strstr (line, " pcrc=")) != NULL) {
-	crc32_t pcrc32 = strtoul (ptr + 6, NULL, 16);
-	if (pcrc32 != yepartcrc) {
-	  UUMessage (uunconc_id, __LINE__, UUMSG_WARNING,
-		     uustring (S_PCRC_MISMATCH), progress.curfile, progress.partno);
-	}
       }
-      if (lastpart && (ptr = FP_strstr (line, " crc32=")) != NULL)
+      if ((ptr = _FP_strstr (line, " crc32=")) != NULL)
       {
 	crc32_t fcrc32 = strtoul (ptr + 7, NULL, 16);
 	if (fcrc32 != yefilecrc) {
@@ -1164,7 +1143,7 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 		     uustring (S_CRC_MISMATCH), progress.curfile);
 	}
       }
-      if ((ptr = FP_strstr (line, " size=")) != NULL)
+      if ((ptr = _FP_strstr (line, " size=")) != NULL)
       {
 	size_t size = atol(ptr + 6);
 	if (size != yepartsize && yefilesize != -1) {
@@ -1178,7 +1157,7 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 		       yepartsize, size);
 	}
       }
-      if (lastpart) {
+      if (yepartends == 0 || yepartends >= yefilesize) {
 	*state = DONE;
       }
       break;
@@ -1206,7 +1185,9 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 	if (tf) {
 	  count  = UUDecodeLine (line, oline, method);
 	  if (method == YENC_ENCODED) {
-	    yepartcrc = uu_crc32(yepartcrc, oline, count);
+	    if (yepartends)
+	      yepartcrc = crc32(yepartcrc, oline, count);
+	    yefilecrc = crc32(yefilecrc, oline, count);
 	    yepartsize += count;
 	  }
 	  vlc++; lc[1]++;
@@ -1234,7 +1215,7 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 	  lc[1] = 3;
 	}
 	else {
-	  FP_strncpy (save[tc++], line, 1200);
+	  _FP_strncpy (save[tc++], line, 1200);
 	}
 
 	if (method == UU_ENCODED)
@@ -1279,7 +1260,7 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
   if (*state  == DONE ||
       (*state == DATA && method == B64ENCODED &&
        vflag == B64ENCODED && (flags&FL_PROPER || haddh))) {
-    for (tf=0; tf<tc; tf++)
+    for (tf=0; tf<tc; tf++) 
       count += UUDecodeLine (save[tf], oline + count, method);
     if (count) {
       if (method == BH_ENCODED) {
@@ -1351,7 +1332,7 @@ UUDecode (uulist *data)
 
   if (!data->binfile) {
 #else
-  if ((data->binfile = tmpnam (NULL)) == NULL) {
+  if ((data->binfile = tempnam (NULL, "uu")) == NULL) {
 #endif /* HAVE_MKSTEMP */
     UUMessage (uunconc_id, __LINE__, UUMSG_ERROR,
 	       uustring (S_NO_TEMP_NAME));
@@ -1363,7 +1344,7 @@ UUDecode (uulist *data)
   strcat(data->binfile, "/");
   strcat(data->binfile, tmpprefix);
 
-  if ((tmpfd = mkstemp(data->binfile)) == -1 ||
+  if ((tmpfd = mkstemp(data->binfile)) == -1 || 
 	  (dataout = fdopen(tmpfd, mode)) == NULL) {
 #else
   if ((dataout = fopen (data->binfile, mode)) == NULL) {
@@ -1381,13 +1362,12 @@ UUDecode (uulist *data)
 		close(tmpfd);
     }
 #endif /* HAVE_MKSTEMP */
-    FP_free (data->binfile);
+    _FP_free (data->binfile);
     data->binfile = NULL;
     uu_errno = errno;
     return UURET_IOERR;
   }
   UUSETBUF (dataout, dataout_buf, uu_wbuf);
-  FP_flockfile (dataout);
 
   /*
    * we don't have begin lines in Base64 or plain text files.
@@ -1413,13 +1393,13 @@ UUDecode (uulist *data)
    */
   progress.action = 0;
   if (data->filename != NULL) {
-    FP_strncpy (progress.curfile,
+    _FP_strncpy (progress.curfile,
 		 (strlen(data->filename)>255)?
 		 (data->filename+strlen(data->filename)-255):data->filename,
 		 256);
   }
   else {
-    FP_strncpy (progress.curfile,
+    _FP_strncpy (progress.curfile,
 		 (strlen(data->binfile)>255)?
 		 (data->binfile+strlen(data->binfile)-255):data->binfile,
 		 256);
@@ -1435,7 +1415,7 @@ UUDecode (uulist *data)
     progress.numparts = (iter->partno)?iter->partno:1;
     iter = iter->NEXT;
   }
-
+  
   /*
    * let's rock!
    */
@@ -1478,10 +1458,9 @@ UUDecode (uulist *data)
 	res = UURET_IOERR;
 	break;
       }
-      FP_strncpy (uugen_fnbuffer, iter->data->sfname, 1024);
+      _FP_strncpy (uugen_fnbuffer, iter->data->sfname, 1024);
     }
     UUSETBUF (datain, datain_buf, uu_rbuf);
-    FP_flockfile (datain);
 
     progress.partno  = part;
     progress.fsize   = (iter->data->length)?iter->data->length:-1;
@@ -1504,7 +1483,7 @@ UUDecode (uulist *data)
     iter = iter->NEXT;
   }
 
-  if (state == DATA &&
+  if (state == DATA && 
       (data->uudet == B64ENCODED || data->uudet == QP_ENCODED ||
        data->uudet == PT_ENCODED))
     state = DONE; /* assume we're done */
@@ -1519,7 +1498,7 @@ UUDecode (uulist *data)
 
   if (res != UURET_OK || (state != DONE && !uu_desperate)) {
     unlink (data->binfile);
-    FP_free (data->binfile);
+    _FP_free (data->binfile);
     data->binfile = NULL;
     data->state  &= ~UUFILE_TMPFILE;
     data->state  |=  UUFILE_ERROR;
@@ -1542,11 +1521,12 @@ UUDecode (uulist *data)
 
   if (data->uudet == BH_ENCODED && data->binfile) {
 #ifdef HAVE_MKSTEMP
-    ntmp = malloc(strlen(tmpdir)+strlen(tmpprefix)+2);
+	  ntmp = malloc(strlen(tmpdir)+strlen(tmpprefix)+2);
+	  
+	  if (ntmp == NULL) {
 #else
-    ntmp = tempnam (NULL);
+    if ((ntmp = tempnam (NULL, "uu")) == NULL) {
 #endif /* HAVE_MKSTEMP */
-    if (ntmp == NULL) {
       UUMessage (uunconc_id, __LINE__, UUMSG_ERROR,
 		 uustring (S_NO_TEMP_NAME));
       progress.action = 0;
@@ -1561,12 +1541,11 @@ UUDecode (uulist *data)
       return UURET_IOERR;
     }
     UUSETBUF (datain, datain_buf, uu_rbuf);
-    FP_flockfile (datain);
 
 #ifdef HAVE_MKSTEMP
     strcpy(ntmp, tmpdir);
     strcat(ntmp, "/");
-    strcat(ntmp, tmpprefix);
+    strcat(ntmp, tmpprefix); 
     if ((tmpfd = mkstemp(ntmp)) == -1 ||
 		(dataout = fdopen(tmpfd, "wb")) == NULL) {
 #else
@@ -1588,12 +1567,11 @@ UUDecode (uulist *data)
       return UURET_IOERR;
     }
     UUSETBUF (dataout, dataout_buf, uu_wbuf);
-    FP_flockfile (dataout);
 
     /*
      * read fork lengths. remember they're in Motorola format
      */
-    r[0] = FP_getc (datain);
+    r[0] = _FP_fgetc (datain);
     hb   = (int) r[0] + 22;
     fseek (datain, (int) r[0] + 12, SEEK_SET);
     fread (r, 1, 8, datain);
@@ -1639,7 +1617,7 @@ UUDecode (uulist *data)
      * copy the chosen fork
      */
 
-    while (!FP_feof (datain) && numbytes) {
+    while (!feof (datain) && numbytes) {
       if (UUBUSYPOLL(ftell(datain)-progress.foffset,progress.fsize)) {
 	UUMessage (uunconc_id, __LINE__, UUMSG_NOTE,
 		   uustring (S_DECODE_CANCEL));
@@ -1655,7 +1633,7 @@ UUDecode (uulist *data)
       bytes = fread (uugen_inbuffer, 1,
 		     (size_t) ((numbytes>1024)?1024:numbytes), datain);
 
-      if (ferror (datain) || (bytes == 0 && !FP_feof (datain))) {
+      if (ferror (datain) || (bytes == 0 && !feof (datain))) {
 	progress.action = 0;
 	UUMessage (uunconc_id, __LINE__, UUMSG_ERROR,
 		   uustring (S_SOURCE_READ_ERR),
@@ -1741,13 +1719,13 @@ UUQuickDecode (FILE *datain, FILE *dataout, char *boundary, long maxpos)
   memset (&myenv, 0, sizeof (headers));
   UUScanHeader (datain, &myenv);
 
-  if (FP_stristr (myenv.ctenc, "uu") != NULL)
+  if (_FP_stristr (myenv.ctenc, "uu") != NULL)
     encoding = UU_ENCODED;
-  else if (FP_stristr (myenv.ctenc, "xx") != NULL)
+  else if (_FP_stristr (myenv.ctenc, "xx") != NULL)
     encoding = XX_ENCODED;
-  else if (FP_stricmp (myenv.ctenc, "base64") == 0)
+  else if (_FP_stricmp (myenv.ctenc, "base64") == 0)
     encoding = B64ENCODED;
-  else if (FP_stricmp (myenv.ctenc, "quoted-printable") == 0)
+  else if (_FP_stricmp (myenv.ctenc, "quoted-printable") == 0)
     encoding = QP_ENCODED;
   else
     encoding = PT_ENCODED;
